WebPack.StartBlocker (reaxt v4.1.2)

this process blocks application start to ensure that when the next application starts the reaxt render is ready (js is compiled)

Summary

Functions

child_spec(arg)

start_link(timeout)

wait(timeout)